import typing

import kubernetes.client

class CoreV1Api:
    def __init__(
        self, api_client: typing.Optional[kubernetes.client.ApiClient] = ...
    ) -> None: ...
    def get_api_resources(self) -> kubernetes.client.V1APIResourceList: ...
    def list_component_status(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ComponentStatusList: ...
    def read_component_status(
        self, name: str, *, pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ComponentStatus: ...
    def list_config_map_for_all_namespaces(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ConfigMapList: ...
    def list_endpoints_for_all_namespaces(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1EndpointsList: ...
    def list_event_for_all_namespaces(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.CoreV1EventList: ...
    def list_limit_range_for_all_namespaces(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1LimitRangeList: ...
    def list_namespace(
        self,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1NamespaceList: ...
    def create_namespace(
        self,
        body: kubernetes.client.V1Namespace,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Namespace: ...
    def create_namespaced_binding(
        self,
        namespace: str,
        body: kubernetes.client.V1Binding,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Binding: ...
    def list_namespaced_config_map(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ConfigMapList: ...
    def create_namespaced_config_map(
        self,
        namespace: str,
        body: kubernetes.client.V1ConfigMap,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ConfigMap: ...
    def delete_collection_namespaced_config_map(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_namespaced_config_map(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ConfigMap: ...
    def replace_namespaced_config_map(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1ConfigMap,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ConfigMap: ...
    def delete_namespaced_config_map(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Status: ...
    def patch_namespaced_config_map(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ConfigMap: ...
    def list_namespaced_endpoints(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1EndpointsList: ...
    def create_namespaced_endpoints(
        self,
        namespace: str,
        body: kubernetes.client.V1Endpoints,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Endpoints: ...
    def delete_collection_namespaced_endpoints(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_namespaced_endpoints(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Endpoints: ...
    def replace_namespaced_endpoints(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1Endpoints,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Endpoints: ...
    def delete_namespaced_endpoints(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Status: ...
    def patch_namespaced_endpoints(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Endpoints: ...
    def list_namespaced_event(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.CoreV1EventList: ...
    def create_namespaced_event(
        self,
        namespace: str,
        body: kubernetes.client.CoreV1Event,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.CoreV1Event: ...
    def delete_collection_namespaced_event(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_namespaced_event(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.CoreV1Event: ...
    def replace_namespaced_event(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.CoreV1Event,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.CoreV1Event: ...
    def delete_namespaced_event(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Status: ...
    def patch_namespaced_event(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.CoreV1Event: ...
    def list_namespaced_limit_range(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1LimitRangeList: ...
    def create_namespaced_limit_range(
        self,
        namespace: str,
        body: kubernetes.client.V1LimitRange,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1LimitRange: ...
    def delete_collection_namespaced_limit_range(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_namespaced_limit_range(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1LimitRange: ...
    def replace_namespaced_limit_range(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1LimitRange,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1LimitRange: ...
    def delete_namespaced_limit_range(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Status: ...
    def patch_namespaced_limit_range(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1LimitRange: ...
    def list_namespaced_persistent_volume_claim(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PersistentVolumeClaimList: ...
    def create_namespaced_persistent_volume_claim(
        self,
        namespace: str,
        body: kubernetes.client.V1PersistentVolumeClaim,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1PersistentVolumeClaim: ...
    def delete_collection_namespaced_persistent_volume_claim(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_namespaced_persistent_volume_claim(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PersistentVolumeClaim: ...
    def replace_namespaced_persistent_volume_claim(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1PersistentVolumeClaim,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1PersistentVolumeClaim: ...
    def delete_namespaced_persistent_volume_claim(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1PersistentVolumeClaim: ...
    def patch_namespaced_persistent_volume_claim(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PersistentVolumeClaim: ...
    def read_namespaced_persistent_volume_claim_status(
        self, name: str, namespace: str, *, pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1PersistentVolumeClaim: ...
    def replace_namespaced_persistent_volume_claim_status(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1PersistentVolumeClaim,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1PersistentVolumeClaim: ...
    def patch_namespaced_persistent_volume_claim_status(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PersistentVolumeClaim: ...
    def list_namespaced_pod(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PodList: ...
    def create_namespaced_pod(
        self,
        namespace: str,
        body: kubernetes.client.V1Pod,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Pod: ...
    def delete_collection_namespaced_pod(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_namespaced_pod(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Pod: ...
    def replace_namespaced_pod(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1Pod,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Pod: ...
    def delete_namespaced_pod(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Pod: ...
    def patch_namespaced_pod(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Pod: ...
    def connect_get_namespaced_pod_attach(
        self,
        name: str,
        namespace: str,
        *,
        container: typing.Optional[str] = ...,
        stderr: typing.Optional[bool] = ...,
        stdin: typing.Optional[bool] = ...,
        stdout: typing.Optional[bool] = ...,
        tty: typing.Optional[bool] = ...
    ) -> str: ...
    def connect_post_namespaced_pod_attach(
        self,
        name: str,
        namespace: str,
        *,
        container: typing.Optional[str] = ...,
        stderr: typing.Optional[bool] = ...,
        stdin: typing.Optional[bool] = ...,
        stdout: typing.Optional[bool] = ...,
        tty: typing.Optional[bool] = ...
    ) -> str: ...
    def create_namespaced_pod_binding(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1Binding,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Binding: ...
    def create_namespaced_pod_eviction(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1beta1Eviction,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1Eviction: ...
    def connect_get_namespaced_pod_exec(
        self,
        name: str,
        namespace: str,
        *,
        command: typing.Optional[str] = ...,
        container: typing.Optional[str] = ...,
        stderr: typing.Optional[bool] = ...,
        stdin: typing.Optional[bool] = ...,
        stdout: typing.Optional[bool] = ...,
        tty: typing.Optional[bool] = ...
    ) -> str: ...
    def connect_post_namespaced_pod_exec(
        self,
        name: str,
        namespace: str,
        *,
        command: typing.Optional[str] = ...,
        container: typing.Optional[str] = ...,
        stderr: typing.Optional[bool] = ...,
        stdin: typing.Optional[bool] = ...,
        stdout: typing.Optional[bool] = ...,
        tty: typing.Optional[bool] = ...
    ) -> str: ...
    def read_namespaced_pod_log(
        self,
        name: str,
        namespace: str,
        *,
        container: typing.Optional[str] = ...,
        follow: typing.Optional[bool] = ...,
        insecure_skip_tls_verify_backend: typing.Optional[bool] = ...,
        limit_bytes: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        previous: typing.Optional[bool] = ...,
        since_seconds: typing.Optional[int] = ...,
        tail_lines: typing.Optional[int] = ...,
        timestamps: typing.Optional[bool] = ...
    ) -> str: ...
    def connect_get_namespaced_pod_portforward(
        self, name: str, namespace: str, *, ports: typing.Optional[int] = ...
    ) -> str: ...
    def connect_post_namespaced_pod_portforward(
        self, name: str, namespace: str, *, ports: typing.Optional[int] = ...
    ) -> str: ...
    def connect_get_namespaced_pod_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_put_namespaced_pod_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_post_namespaced_pod_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_delete_namespaced_pod_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_options_namespaced_pod_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_head_namespaced_pod_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_patch_namespaced_pod_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_get_namespaced_pod_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_put_namespaced_pod_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_post_namespaced_pod_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_delete_namespaced_pod_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_options_namespaced_pod_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_head_namespaced_pod_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_patch_namespaced_pod_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def read_namespaced_pod_status(
        self, name: str, namespace: str, *, pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Pod: ...
    def replace_namespaced_pod_status(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1Pod,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Pod: ...
    def patch_namespaced_pod_status(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Pod: ...
    def list_namespaced_pod_template(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PodTemplateList: ...
    def create_namespaced_pod_template(
        self,
        namespace: str,
        body: kubernetes.client.V1PodTemplate,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1PodTemplate: ...
    def delete_collection_namespaced_pod_template(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_namespaced_pod_template(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PodTemplate: ...
    def replace_namespaced_pod_template(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1PodTemplate,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1PodTemplate: ...
    def delete_namespaced_pod_template(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1PodTemplate: ...
    def patch_namespaced_pod_template(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PodTemplate: ...
    def list_namespaced_replication_controller(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ReplicationControllerList: ...
    def create_namespaced_replication_controller(
        self,
        namespace: str,
        body: kubernetes.client.V1ReplicationController,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ReplicationController: ...
    def delete_collection_namespaced_replication_controller(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_namespaced_replication_controller(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ReplicationController: ...
    def replace_namespaced_replication_controller(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1ReplicationController,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ReplicationController: ...
    def delete_namespaced_replication_controller(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Status: ...
    def patch_namespaced_replication_controller(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ReplicationController: ...
    def read_namespaced_replication_controller_scale(
        self, name: str, namespace: str, *, pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Scale: ...
    def replace_namespaced_replication_controller_scale(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1Scale,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Scale: ...
    def patch_namespaced_replication_controller_scale(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Scale: ...
    def read_namespaced_replication_controller_status(
        self, name: str, namespace: str, *, pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ReplicationController: ...
    def replace_namespaced_replication_controller_status(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1ReplicationController,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ReplicationController: ...
    def patch_namespaced_replication_controller_status(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ReplicationController: ...
    def list_namespaced_resource_quota(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ResourceQuotaList: ...
    def create_namespaced_resource_quota(
        self,
        namespace: str,
        body: kubernetes.client.V1ResourceQuota,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ResourceQuota: ...
    def delete_collection_namespaced_resource_quota(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_namespaced_resource_quota(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ResourceQuota: ...
    def replace_namespaced_resource_quota(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1ResourceQuota,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ResourceQuota: ...
    def delete_namespaced_resource_quota(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ResourceQuota: ...
    def patch_namespaced_resource_quota(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ResourceQuota: ...
    def read_namespaced_resource_quota_status(
        self, name: str, namespace: str, *, pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ResourceQuota: ...
    def replace_namespaced_resource_quota_status(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1ResourceQuota,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ResourceQuota: ...
    def patch_namespaced_resource_quota_status(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ResourceQuota: ...
    def list_namespaced_secret(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1SecretList: ...
    def create_namespaced_secret(
        self,
        namespace: str,
        body: kubernetes.client.V1Secret,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Secret: ...
    def delete_collection_namespaced_secret(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_namespaced_secret(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Secret: ...
    def replace_namespaced_secret(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1Secret,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Secret: ...
    def delete_namespaced_secret(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Status: ...
    def patch_namespaced_secret(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Secret: ...
    def list_namespaced_service_account(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ServiceAccountList: ...
    def create_namespaced_service_account(
        self,
        namespace: str,
        body: kubernetes.client.V1ServiceAccount,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ServiceAccount: ...
    def delete_collection_namespaced_service_account(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_namespaced_service_account(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ServiceAccount: ...
    def replace_namespaced_service_account(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1ServiceAccount,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ServiceAccount: ...
    def delete_namespaced_service_account(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1ServiceAccount: ...
    def patch_namespaced_service_account(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ServiceAccount: ...
    def create_namespaced_service_account_token(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.AuthenticationV1TokenRequest,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.AuthenticationV1TokenRequest: ...
    def list_namespaced_service(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ServiceList: ...
    def create_namespaced_service(
        self,
        namespace: str,
        body: kubernetes.client.V1Service,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Service: ...
    def read_namespaced_service(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Service: ...
    def replace_namespaced_service(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1Service,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Service: ...
    def delete_namespaced_service(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Status: ...
    def patch_namespaced_service(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Service: ...
    def connect_get_namespaced_service_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_put_namespaced_service_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_post_namespaced_service_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_delete_namespaced_service_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_options_namespaced_service_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_head_namespaced_service_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_patch_namespaced_service_proxy(
        self, name: str, namespace: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_get_namespaced_service_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_put_namespaced_service_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_post_namespaced_service_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_delete_namespaced_service_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_options_namespaced_service_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_head_namespaced_service_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_patch_namespaced_service_proxy_with_path(
        self, name: str, namespace: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def read_namespaced_service_status(
        self, name: str, namespace: str, *, pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Service: ...
    def replace_namespaced_service_status(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1Service,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Service: ...
    def patch_namespaced_service_status(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Service: ...
    def read_namespace(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Namespace: ...
    def replace_namespace(
        self,
        name: str,
        body: kubernetes.client.V1Namespace,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Namespace: ...
    def delete_namespace(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Status: ...
    def patch_namespace(
        self,
        name: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Namespace: ...
    def replace_namespace_finalize(
        self,
        name: str,
        body: kubernetes.client.V1Namespace,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Namespace: ...
    def read_namespace_status(
        self, name: str, *, pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Namespace: ...
    def replace_namespace_status(
        self,
        name: str,
        body: kubernetes.client.V1Namespace,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Namespace: ...
    def patch_namespace_status(
        self,
        name: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Namespace: ...
    def list_node(
        self,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1NodeList: ...
    def create_node(
        self,
        body: kubernetes.client.V1Node,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Node: ...
    def delete_collection_node(
        self,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_node(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Node: ...
    def replace_node(
        self,
        name: str,
        body: kubernetes.client.V1Node,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Node: ...
    def delete_node(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Status: ...
    def patch_node(
        self,
        name: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Node: ...
    def connect_get_node_proxy(
        self, name: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_put_node_proxy(
        self, name: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_post_node_proxy(
        self, name: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_delete_node_proxy(
        self, name: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_options_node_proxy(
        self, name: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_head_node_proxy(
        self, name: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_patch_node_proxy(
        self, name: str, *, path: typing.Optional[str] = ...
    ) -> str: ...
    def connect_get_node_proxy_with_path(
        self, name: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_put_node_proxy_with_path(
        self, name: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_post_node_proxy_with_path(
        self, name: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_delete_node_proxy_with_path(
        self, name: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_options_node_proxy_with_path(
        self, name: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_head_node_proxy_with_path(
        self, name: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def connect_patch_node_proxy_with_path(
        self, name: str, path: str, *, path2: typing.Optional[str] = ...
    ) -> str: ...
    def read_node_status(
        self, name: str, *, pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Node: ...
    def replace_node_status(
        self,
        name: str,
        body: kubernetes.client.V1Node,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Node: ...
    def patch_node_status(
        self,
        name: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1Node: ...
    def list_persistent_volume_claim_for_all_namespaces(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PersistentVolumeClaimList: ...
    def list_persistent_volume(
        self,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PersistentVolumeList: ...
    def create_persistent_volume(
        self,
        body: kubernetes.client.V1PersistentVolume,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1PersistentVolume: ...
    def delete_collection_persistent_volume(
        self,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_persistent_volume(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PersistentVolume: ...
    def replace_persistent_volume(
        self,
        name: str,
        body: kubernetes.client.V1PersistentVolume,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1PersistentVolume: ...
    def delete_persistent_volume(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1PersistentVolume: ...
    def patch_persistent_volume(
        self,
        name: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PersistentVolume: ...
    def read_persistent_volume_status(
        self, name: str, *, pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1PersistentVolume: ...
    def replace_persistent_volume_status(
        self,
        name: str,
        body: kubernetes.client.V1PersistentVolume,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1PersistentVolume: ...
    def patch_persistent_volume_status(
        self,
        name: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PersistentVolume: ...
    def list_pod_for_all_namespaces(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PodList: ...
    def list_pod_template_for_all_namespaces(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1PodTemplateList: ...
    def list_replication_controller_for_all_namespaces(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ReplicationControllerList: ...
    def list_resource_quota_for_all_namespaces(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ResourceQuotaList: ...
    def list_secret_for_all_namespaces(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1SecretList: ...
    def list_service_account_for_all_namespaces(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ServiceAccountList: ...
    def list_service_for_all_namespaces(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1ServiceList: ...



import datetime
import typing

import kubernetes.client

class V1DeploymentSpec:
    min_ready_seconds: typing.Optional[int]
    paused: typing.Optional[bool]
    progress_deadline_seconds: typing.Optional[int]
    replicas: typing.Optional[int]
    revision_history_limit: typing.Optional[int]
    selector: kubernetes.client.V1LabelSelector
    strategy: typing.Optional[kubernetes.client.V1DeploymentStrategy]
    template: kubernetes.client.V1PodTemplateSpec
    def __init__(
        self,
        *,
        min_ready_seconds: typing.Optional[int] = ...,
        paused: typing.Optional[bool] = ...,
        progress_deadline_seconds: typing.Optional[int] = ...,
        replicas: typing.Optional[int] = ...,
        revision_history_limit: typing.Optional[int] = ...,
        selector: kubernetes.client.V1LabelSelector,
        strategy: typing.Optional[kubernetes.client.V1DeploymentStrategy] = ...,
        template: kubernetes.client.V1PodTemplateSpec
    ) -> None: ...
    def to_dict(self) -> V1DeploymentSpecDict: ...

class V1DeploymentSpecDict(typing.TypedDict, total=False):
    minReadySeconds: typing.Optional[int]
    paused: typing.Optional[bool]
    progressDeadlineSeconds: typing.Optional[int]
    replicas: typing.Optional[int]
    revisionHistoryLimit: typing.Optional[int]
    selector: kubernetes.client.V1LabelSelectorDict
    strategy: typing.Optional[kubernetes.client.V1DeploymentStrategyDict]
    template: kubernetes.client.V1PodTemplateSpecDict



import datetime
import typing

import kubernetes.client

class V1DeploymentStrategy:
    rolling_update: typing.Optional[kubernetes.client.V1RollingUpdateDeployment]
    type: typing.Optional[str]
    def __init__(
        self,
        *,
        rolling_update: typing.Optional[
            kubernetes.client.V1RollingUpdateDeployment
        ] = ...,
        type: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1DeploymentStrategyDict: ...

class V1DeploymentStrategyDict(typing.TypedDict, total=False):
    rollingUpdate: typing.Optional[kubernetes.client.V1RollingUpdateDeploymentDict]
    type: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V2beta2MetricValueStatus:
    average_utilization: typing.Optional[int]
    average_value: typing.Optional[str]
    value: typing.Optional[str]
    def __init__(
        self,
        *,
        average_utilization: typing.Optional[int] = ...,
        average_value: typing.Optional[str] = ...,
        value: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V2beta2MetricValueStatusDict: ...

class V2beta2MetricValueStatusDict(typing.TypedDict, total=False):
    averageUtilization: typing.Optional[int]
    averageValue: typing.Optional[str]
    value: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1PersistentVolumeSpec:
    access_modes: typing.Optional[list[str]]
    aws_elastic_block_store: typing.Optional[
        kubernetes.client.V1AWSElasticBlockStoreVolumeSource
    ]
    azure_disk: typing.Optional[kubernetes.client.V1AzureDiskVolumeSource]
    azure_file: typing.Optional[kubernetes.client.V1AzureFilePersistentVolumeSource]
    capacity: typing.Optional[dict[str, str]]
    cephfs: typing.Optional[kubernetes.client.V1CephFSPersistentVolumeSource]
    cinder: typing.Optional[kubernetes.client.V1CinderPersistentVolumeSource]
    claim_ref: typing.Optional[kubernetes.client.V1ObjectReference]
    csi: typing.Optional[kubernetes.client.V1CSIPersistentVolumeSource]
    fc: typing.Optional[kubernetes.client.V1FCVolumeSource]
    flex_volume: typing.Optional[kubernetes.client.V1FlexPersistentVolumeSource]
    flocker: typing.Optional[kubernetes.client.V1FlockerVolumeSource]
    gce_persistent_disk: typing.Optional[
        kubernetes.client.V1GCEPersistentDiskVolumeSource
    ]
    glusterfs: typing.Optional[kubernetes.client.V1GlusterfsPersistentVolumeSource]
    host_path: typing.Optional[kubernetes.client.V1HostPathVolumeSource]
    iscsi: typing.Optional[kubernetes.client.V1ISCSIPersistentVolumeSource]
    local: typing.Optional[kubernetes.client.V1LocalVolumeSource]
    mount_options: typing.Optional[list[str]]
    nfs: typing.Optional[kubernetes.client.V1NFSVolumeSource]
    node_affinity: typing.Optional[kubernetes.client.V1VolumeNodeAffinity]
    persistent_volume_reclaim_policy: typing.Optional[str]
    photon_persistent_disk: typing.Optional[
        kubernetes.client.V1PhotonPersistentDiskVolumeSource
    ]
    portworx_volume: typing.Optional[kubernetes.client.V1PortworxVolumeSource]
    quobyte: typing.Optional[kubernetes.client.V1QuobyteVolumeSource]
    rbd: typing.Optional[kubernetes.client.V1RBDPersistentVolumeSource]
    scale_io: typing.Optional[kubernetes.client.V1ScaleIOPersistentVolumeSource]
    storage_class_name: typing.Optional[str]
    storageos: typing.Optional[kubernetes.client.V1StorageOSPersistentVolumeSource]
    volume_mode: typing.Optional[str]
    vsphere_volume: typing.Optional[kubernetes.client.V1VsphereVirtualDiskVolumeSource]
    def __init__(
        self,
        *,
        access_modes: typing.Optional[list[str]] = ...,
        aws_elastic_block_store: typing.Optional[
            kubernetes.client.V1AWSElasticBlockStoreVolumeSource
        ] = ...,
        azure_disk: typing.Optional[kubernetes.client.V1AzureDiskVolumeSource] = ...,
        azure_file: typing.Optional[
            kubernetes.client.V1AzureFilePersistentVolumeSource
        ] = ...,
        capacity: typing.Optional[dict[str, str]] = ...,
        cephfs: typing.Optional[kubernetes.client.V1CephFSPersistentVolumeSource] = ...,
        cinder: typing.Optional[kubernetes.client.V1CinderPersistentVolumeSource] = ...,
        claim_ref: typing.Optional[kubernetes.client.V1ObjectReference] = ...,
        csi: typing.Optional[kubernetes.client.V1CSIPersistentVolumeSource] = ...,
        fc: typing.Optional[kubernetes.client.V1FCVolumeSource] = ...,
        flex_volume: typing.Optional[
            kubernetes.client.V1FlexPersistentVolumeSource
        ] = ...,
        flocker: typing.Optional[kubernetes.client.V1FlockerVolumeSource] = ...,
        gce_persistent_disk: typing.Optional[
            kubernetes.client.V1GCEPersistentDiskVolumeSource
        ] = ...,
        glusterfs: typing.Optional[
            kubernetes.client.V1GlusterfsPersistentVolumeSource
        ] = ...,
        host_path: typing.Optional[kubernetes.client.V1HostPathVolumeSource] = ...,
        iscsi: typing.Optional[kubernetes.client.V1ISCSIPersistentVolumeSource] = ...,
        local: typing.Optional[kubernetes.client.V1LocalVolumeSource] = ...,
        mount_options: typing.Optional[list[str]] = ...,
        nfs: typing.Optional[kubernetes.client.V1NFSVolumeSource] = ...,
        node_affinity: typing.Optional[kubernetes.client.V1VolumeNodeAffinity] = ...,
        persistent_volume_reclaim_policy: typing.Optional[str] = ...,
        photon_persistent_disk: typing.Optional[
            kubernetes.client.V1PhotonPersistentDiskVolumeSource
        ] = ...,
        portworx_volume: typing.Optional[
            kubernetes.client.V1PortworxVolumeSource
        ] = ...,
        quobyte: typing.Optional[kubernetes.client.V1QuobyteVolumeSource] = ...,
        rbd: typing.Optional[kubernetes.client.V1RBDPersistentVolumeSource] = ...,
        scale_io: typing.Optional[
            kubernetes.client.V1ScaleIOPersistentVolumeSource
        ] = ...,
        storage_class_name: typing.Optional[str] = ...,
        storageos: typing.Optional[
            kubernetes.client.V1StorageOSPersistentVolumeSource
        ] = ...,
        volume_mode: typing.Optional[str] = ...,
        vsphere_volume: typing.Optional[
            kubernetes.client.V1VsphereVirtualDiskVolumeSource
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1PersistentVolumeSpecDict: ...

class V1PersistentVolumeSpecDict(typing.TypedDict, total=False):
    accessModes: typing.Optional[list[str]]
    awsElasticBlockStore: typing.Optional[
        kubernetes.client.V1AWSElasticBlockStoreVolumeSourceDict
    ]
    azureDisk: typing.Optional[kubernetes.client.V1AzureDiskVolumeSourceDict]
    azureFile: typing.Optional[kubernetes.client.V1AzureFilePersistentVolumeSourceDict]
    capacity: typing.Optional[dict[str, str]]
    cephfs: typing.Optional[kubernetes.client.V1CephFSPersistentVolumeSourceDict]
    cinder: typing.Optional[kubernetes.client.V1CinderPersistentVolumeSourceDict]
    claimRef: typing.Optional[kubernetes.client.V1ObjectReferenceDict]
    csi: typing.Optional[kubernetes.client.V1CSIPersistentVolumeSourceDict]
    fc: typing.Optional[kubernetes.client.V1FCVolumeSourceDict]
    flexVolume: typing.Optional[kubernetes.client.V1FlexPersistentVolumeSourceDict]
    flocker: typing.Optional[kubernetes.client.V1FlockerVolumeSourceDict]
    gcePersistentDisk: typing.Optional[
        kubernetes.client.V1GCEPersistentDiskVolumeSourceDict
    ]
    glusterfs: typing.Optional[kubernetes.client.V1GlusterfsPersistentVolumeSourceDict]
    hostPath: typing.Optional[kubernetes.client.V1HostPathVolumeSourceDict]
    iscsi: typing.Optional[kubernetes.client.V1ISCSIPersistentVolumeSourceDict]
    local: typing.Optional[kubernetes.client.V1LocalVolumeSourceDict]
    mountOptions: typing.Optional[list[str]]
    nfs: typing.Optional[kubernetes.client.V1NFSVolumeSourceDict]
    nodeAffinity: typing.Optional[kubernetes.client.V1VolumeNodeAffinityDict]
    persistentVolumeReclaimPolicy: typing.Optional[str]
    photonPersistentDisk: typing.Optional[
        kubernetes.client.V1PhotonPersistentDiskVolumeSourceDict
    ]
    portworxVolume: typing.Optional[kubernetes.client.V1PortworxVolumeSourceDict]
    quobyte: typing.Optional[kubernetes.client.V1QuobyteVolumeSourceDict]
    rbd: typing.Optional[kubernetes.client.V1RBDPersistentVolumeSourceDict]
    scaleIO: typing.Optional[kubernetes.client.V1ScaleIOPersistentVolumeSourceDict]
    storageClassName: typing.Optional[str]
    storageos: typing.Optional[kubernetes.client.V1StorageOSPersistentVolumeSourceDict]
    volumeMode: typing.Optional[str]
    vsphereVolume: typing.Optional[
        kubernetes.client.V1VsphereVirtualDiskVolumeSourceDict
    ]



import datetime
import typing

import kubernetes.client

class V1StatefulSetUpdateStrategy:
    rolling_update: typing.Optional[
        kubernetes.client.V1RollingUpdateStatefulSetStrategy
    ]
    type: typing.Optional[str]
    def __init__(
        self,
        *,
        rolling_update: typing.Optional[
            kubernetes.client.V1RollingUpdateStatefulSetStrategy
        ] = ...,
        type: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1StatefulSetUpdateStrategyDict: ...

class V1StatefulSetUpdateStrategyDict(typing.TypedDict, total=False):
    rollingUpdate: typing.Optional[
        kubernetes.client.V1RollingUpdateStatefulSetStrategyDict
    ]
    type: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1TopologySelectorTerm:
    match_label_expressions: typing.Optional[
        list[kubernetes.client.V1TopologySelectorLabelRequirement]
    ]
    def __init__(
        self,
        *,
        match_label_expressions: typing.Optional[
            list[kubernetes.client.V1TopologySelectorLabelRequirement]
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1TopologySelectorTermDict: ...

class V1TopologySelectorTermDict(typing.TypedDict, total=False):
    matchLabelExpressions: typing.Optional[
        list[kubernetes.client.V1TopologySelectorLabelRequirementDict]
    ]



import datetime
import typing

import kubernetes.client

class V1ServiceBackendPort:
    name: typing.Optional[str]
    number: typing.Optional[int]
    def __init__(
        self, *, name: typing.Optional[str] = ..., number: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1ServiceBackendPortDict: ...

class V1ServiceBackendPortDict(typing.TypedDict, total=False):
    name: typing.Optional[str]
    number: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1LabelSelector:
    match_expressions: typing.Optional[
        list[kubernetes.client.V1LabelSelectorRequirement]
    ]
    match_labels: typing.Optional[dict[str, str]]
    def __init__(
        self,
        *,
        match_expressions: typing.Optional[
            list[kubernetes.client.V1LabelSelectorRequirement]
        ] = ...,
        match_labels: typing.Optional[dict[str, str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1LabelSelectorDict: ...

class V1LabelSelectorDict(typing.TypedDict, total=False):
    matchExpressions: typing.Optional[
        list[kubernetes.client.V1LabelSelectorRequirementDict]
    ]
    matchLabels: typing.Optional[dict[str, str]]



import datetime
import typing

import kubernetes.client

class V1PodCondition:
    last_probe_time: typing.Optional[datetime.datetime]
    last_transition_time: typing.Optional[datetime.datetime]
    message: typing.Optional[str]
    reason: typing.Optional[str]
    status: str
    type: str
    def __init__(
        self,
        *,
        last_probe_time: typing.Optional[datetime.datetime] = ...,
        last_transition_time: typing.Optional[datetime.datetime] = ...,
        message: typing.Optional[str] = ...,
        reason: typing.Optional[str] = ...,
        status: str,
        type: str
    ) -> None: ...
    def to_dict(self) -> V1PodConditionDict: ...

class V1PodConditionDict(typing.TypedDict, total=False):
    lastProbeTime: typing.Optional[datetime.datetime]
    lastTransitionTime: typing.Optional[datetime.datetime]
    message: typing.Optional[str]
    reason: typing.Optional[str]
    status: str
    type: str



import datetime
import typing

import kubernetes.client

class V1alpha1ServerStorageVersion:
    api_server_id: typing.Optional[str]
    decodable_versions: typing.Optional[list[str]]
    encoding_version: typing.Optional[str]
    def __init__(
        self,
        *,
        api_server_id: typing.Optional[str] = ...,
        decodable_versions: typing.Optional[list[str]] = ...,
        encoding_version: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1alpha1ServerStorageVersionDict: ...

class V1alpha1ServerStorageVersionDict(typing.TypedDict, total=False):
    apiServerID: typing.Optional[str]
    decodableVersions: typing.Optional[list[str]]
    encodingVersion: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class AdmissionregistrationV1WebhookClientConfig:
    ca_bundle: typing.Optional[str]
    service: typing.Optional[kubernetes.client.AdmissionregistrationV1ServiceReference]
    url: typing.Optional[str]
    def __init__(
        self,
        *,
        ca_bundle: typing.Optional[str] = ...,
        service: typing.Optional[
            kubernetes.client.AdmissionregistrationV1ServiceReference
        ] = ...,
        url: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> AdmissionregistrationV1WebhookClientConfigDict: ...

class AdmissionregistrationV1WebhookClientConfigDict(typing.TypedDict, total=False):
    caBundle: typing.Optional[str]
    service: typing.Optional[
        kubernetes.client.AdmissionregistrationV1ServiceReferenceDict
    ]
    url: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1APIResource:
    categories: typing.Optional[list[str]]
    group: typing.Optional[str]
    kind: str
    name: str
    namespaced: bool
    short_names: typing.Optional[list[str]]
    singular_name: str
    storage_version_hash: typing.Optional[str]
    verbs: list[str]
    version: typing.Optional[str]
    def __init__(
        self,
        *,
        categories: typing.Optional[list[str]] = ...,
        group: typing.Optional[str] = ...,
        kind: str,
        name: str,
        namespaced: bool,
        short_names: typing.Optional[list[str]] = ...,
        singular_name: str,
        storage_version_hash: typing.Optional[str] = ...,
        verbs: list[str],
        version: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1APIResourceDict: ...

class V1APIResourceDict(typing.TypedDict, total=False):
    categories: typing.Optional[list[str]]
    group: typing.Optional[str]
    kind: str
    name: str
    namespaced: bool
    shortNames: typing.Optional[list[str]]
    singularName: str
    storageVersionHash: typing.Optional[str]
    verbs: list[str]
    version: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1ResourceAttributes:
    group: typing.Optional[str]
    name: typing.Optional[str]
    namespace: typing.Optional[str]
    resource: typing.Optional[str]
    subresource: typing.Optional[str]
    verb: typing.Optional[str]
    version: typing.Optional[str]
    def __init__(
        self,
        *,
        group: typing.Optional[str] = ...,
        name: typing.Optional[str] = ...,
        namespace: typing.Optional[str] = ...,
        resource: typing.Optional[str] = ...,
        subresource: typing.Optional[str] = ...,
        verb: typing.Optional[str] = ...,
        version: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1ResourceAttributesDict: ...

class V1ResourceAttributesDict(typing.TypedDict, total=False):
    group: typing.Optional[str]
    name: typing.Optional[str]
    namespace: typing.Optional[str]
    resource: typing.Optional[str]
    subresource: typing.Optional[str]
    verb: typing.Optional[str]
    version: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1ServiceSpec:
    allocate_load_balancer_node_ports: typing.Optional[bool]
    cluster_ip: typing.Optional[str]
    cluster_i_ps: typing.Optional[list[str]]
    external_i_ps: typing.Optional[list[str]]
    external_name: typing.Optional[str]
    external_traffic_policy: typing.Optional[str]
    health_check_node_port: typing.Optional[int]
    ip_families: typing.Optional[list[str]]
    ip_family_policy: typing.Optional[str]
    load_balancer_ip: typing.Optional[str]
    load_balancer_source_ranges: typing.Optional[list[str]]
    ports: typing.Optional[list[kubernetes.client.V1ServicePort]]
    publish_not_ready_addresses: typing.Optional[bool]
    selector: typing.Optional[dict[str, str]]
    session_affinity: typing.Optional[str]
    session_affinity_config: typing.Optional[kubernetes.client.V1SessionAffinityConfig]
    topology_keys: typing.Optional[list[str]]
    type: typing.Optional[str]
    def __init__(
        self,
        *,
        allocate_load_balancer_node_ports: typing.Optional[bool] = ...,
        cluster_ip: typing.Optional[str] = ...,
        cluster_i_ps: typing.Optional[list[str]] = ...,
        external_i_ps: typing.Optional[list[str]] = ...,
        external_name: typing.Optional[str] = ...,
        external_traffic_policy: typing.Optional[str] = ...,
        health_check_node_port: typing.Optional[int] = ...,
        ip_families: typing.Optional[list[str]] = ...,
        ip_family_policy: typing.Optional[str] = ...,
        load_balancer_ip: typing.Optional[str] = ...,
        load_balancer_source_ranges: typing.Optional[list[str]] = ...,
        ports: typing.Optional[list[kubernetes.client.V1ServicePort]] = ...,
        publish_not_ready_addresses: typing.Optional[bool] = ...,
        selector: typing.Optional[dict[str, str]] = ...,
        session_affinity: typing.Optional[str] = ...,
        session_affinity_config: typing.Optional[
            kubernetes.client.V1SessionAffinityConfig
        ] = ...,
        topology_keys: typing.Optional[list[str]] = ...,
        type: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1ServiceSpecDict: ...

class V1ServiceSpecDict(typing.TypedDict, total=False):
    allocateLoadBalancerNodePorts: typing.Optional[bool]
    clusterIP: typing.Optional[str]
    clusterIPs: typing.Optional[list[str]]
    externalIPs: typing.Optional[list[str]]
    externalName: typing.Optional[str]
    externalTrafficPolicy: typing.Optional[str]
    healthCheckNodePort: typing.Optional[int]
    ipFamilies: typing.Optional[list[str]]
    ipFamilyPolicy: typing.Optional[str]
    loadBalancerIP: typing.Optional[str]
    loadBalancerSourceRanges: typing.Optional[list[str]]
    ports: typing.Optional[list[kubernetes.client.V1ServicePortDict]]
    publishNotReadyAddresses: typing.Optional[bool]
    selector: typing.Optional[dict[str, str]]
    sessionAffinity: typing.Optional[str]
    sessionAffinityConfig: typing.Optional[
        kubernetes.client.V1SessionAffinityConfigDict
    ]
    topologyKeys: typing.Optional[list[str]]
    type: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1ManagedFieldsEntry:
    api_version: typing.Optional[str]
    fields_type: typing.Optional[str]
    fields_v1: typing.Optional[typing.Any]
    manager: typing.Optional[str]
    operation: typing.Optional[str]
    time: typing.Optional[datetime.datetime]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        fields_type: typing.Optional[str] = ...,
        fields_v1: typing.Optional[typing.Any] = ...,
        manager: typing.Optional[str] = ...,
        operation: typing.Optional[str] = ...,
        time: typing.Optional[datetime.datetime] = ...
    ) -> None: ...
    def to_dict(self) -> V1ManagedFieldsEntryDict: ...

class V1ManagedFieldsEntryDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    fieldsType: typing.Optional[str]
    fieldsV1: typing.Optional[typing.Any]
    manager: typing.Optional[str]
    operation: typing.Optional[str]
    time: typing.Optional[datetime.datetime]



import datetime
import typing

import kubernetes.client

class V1AzureFilePersistentVolumeSource:
    read_only: typing.Optional[bool]
    secret_name: str
    secret_namespace: typing.Optional[str]
    share_name: str
    def __init__(
        self,
        *,
        read_only: typing.Optional[bool] = ...,
        secret_name: str,
        secret_namespace: typing.Optional[str] = ...,
        share_name: str
    ) -> None: ...
    def to_dict(self) -> V1AzureFilePersistentVolumeSourceDict: ...

class V1AzureFilePersistentVolumeSourceDict(typing.TypedDict, total=False):
    readOnly: typing.Optional[bool]
    secretName: str
    secretNamespace: typing.Optional[str]
    shareName: str



import datetime
import typing

import kubernetes.client

class V1JSONSchemaProps:
    ref: typing.Optional[str]
    schema: typing.Optional[str]
    additional_items: typing.Optional[typing.Any]
    additional_properties: typing.Optional[typing.Any]
    all_of: typing.Optional[list[kubernetes.client.V1JSONSchemaProps]]
    any_of: typing.Optional[list[kubernetes.client.V1JSONSchemaProps]]
    default: typing.Optional[typing.Any]
    definitions: typing.Optional[dict[str, kubernetes.client.V1JSONSchemaProps]]
    dependencies: typing.Optional[dict[str, typing.Any]]
    description: typing.Optional[str]
    enum: typing.Optional[list[typing.Any]]
    example: typing.Optional[typing.Any]
    exclusive_maximum: typing.Optional[bool]
    exclusive_minimum: typing.Optional[bool]
    external_docs: typing.Optional[kubernetes.client.V1ExternalDocumentation]
    format: typing.Optional[str]
    id: typing.Optional[str]
    items: typing.Optional[typing.Any]
    max_items: typing.Optional[int]
    max_length: typing.Optional[int]
    max_properties: typing.Optional[int]
    maximum: typing.Optional[float]
    min_items: typing.Optional[int]
    min_length: typing.Optional[int]
    min_properties: typing.Optional[int]
    minimum: typing.Optional[float]
    multiple_of: typing.Optional[float]
    _not: typing.Optional[kubernetes.client.V1JSONSchemaProps]
    nullable: typing.Optional[bool]
    one_of: typing.Optional[list[kubernetes.client.V1JSONSchemaProps]]
    pattern: typing.Optional[str]
    pattern_properties: typing.Optional[dict[str, kubernetes.client.V1JSONSchemaProps]]
    properties: typing.Optional[dict[str, kubernetes.client.V1JSONSchemaProps]]
    required: typing.Optional[list[str]]
    title: typing.Optional[str]
    type: typing.Optional[str]
    unique_items: typing.Optional[bool]
    x_kubernetes_embedded_resource: typing.Optional[bool]
    x_kubernetes_int_or_string: typing.Optional[bool]
    x_kubernetes_list_map_keys: typing.Optional[list[str]]
    x_kubernetes_list_type: typing.Optional[str]
    x_kubernetes_map_type: typing.Optional[str]
    x_kubernetes_preserve_unknown_fields: typing.Optional[bool]
    def __init__(
        self,
        *,
        ref: typing.Optional[str] = ...,
        schema: typing.Optional[str] = ...,
        additional_items: typing.Optional[typing.Any] = ...,
        additional_properties: typing.Optional[typing.Any] = ...,
        all_of: typing.Optional[list[kubernetes.client.V1JSONSchemaProps]] = ...,
        any_of: typing.Optional[list[kubernetes.client.V1JSONSchemaProps]] = ...,
        default: typing.Optional[typing.Any] = ...,
        definitions: typing.Optional[
            dict[str, kubernetes.client.V1JSONSchemaProps]
        ] = ...,
        dependencies: typing.Optional[dict[str, typing.Any]] = ...,
        description: typing.Optional[str] = ...,
        enum: typing.Optional[list[typing.Any]] = ...,
        example: typing.Optional[typing.Any] = ...,
        exclusive_maximum: typing.Optional[bool] = ...,
        exclusive_minimum: typing.Optional[bool] = ...,
        external_docs: typing.Optional[kubernetes.client.V1ExternalDocumentation] = ...,
        format: typing.Optional[str] = ...,
        id: typing.Optional[str] = ...,
        items: typing.Optional[typing.Any] = ...,
        max_items: typing.Optional[int] = ...,
        max_length: typing.Optional[int] = ...,
        max_properties: typing.Optional[int] = ...,
        maximum: typing.Optional[float] = ...,
        min_items: typing.Optional[int] = ...,
        min_length: typing.Optional[int] = ...,
        min_properties: typing.Optional[int] = ...,
        minimum: typing.Optional[float] = ...,
        multiple_of: typing.Optional[float] = ...,
        _not: typing.Optional[kubernetes.client.V1JSONSchemaProps] = ...,
        nullable: typing.Optional[bool] = ...,
        one_of: typing.Optional[list[kubernetes.client.V1JSONSchemaProps]] = ...,
        pattern: typing.Optional[str] = ...,
        pattern_properties: typing.Optional[
            dict[str, kubernetes.client.V1JSONSchemaProps]
        ] = ...,
        properties: typing.Optional[
            dict[str, kubernetes.client.V1JSONSchemaProps]
        ] = ...,
        required: typing.Optional[list[str]] = ...,
        title: typing.Optional[str] = ...,
        type: typing.Optional[str] = ...,
        unique_items: typing.Optional[bool] = ...,
        x_kubernetes_embedded_resource: typing.Optional[bool] = ...,
        x_kubernetes_int_or_string: typing.Optional[bool] = ...,
        x_kubernetes_list_map_keys: typing.Optional[list[str]] = ...,
        x_kubernetes_list_type: typing.Optional[str] = ...,
        x_kubernetes_map_type: typing.Optional[str] = ...,
        x_kubernetes_preserve_unknown_fields: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1JSONSchemaPropsDict: ...

class V1JSONSchemaPropsDict(typing.TypedDict, total=False):
    ref: typing.Optional[str]
    schema: typing.Optional[str]
    additionalItems: typing.Optional[typing.Any]
    additionalProperties: typing.Optional[typing.Any]
    allOf: typing.Optional[list[kubernetes.client.V1JSONSchemaPropsDict]]
    anyOf: typing.Optional[list[kubernetes.client.V1JSONSchemaPropsDict]]
    default: typing.Optional[typing.Any]
    definitions: typing.Optional[dict[str, kubernetes.client.V1JSONSchemaPropsDict]]
    dependencies: typing.Optional[dict[str, typing.Any]]
    description: typing.Optional[str]
    enum: typing.Optional[list[typing.Any]]
    example: typing.Optional[typing.Any]
    exclusiveMaximum: typing.Optional[bool]
    exclusiveMinimum: typing.Optional[bool]
    externalDocs: typing.Optional[kubernetes.client.V1ExternalDocumentationDict]
    format: typing.Optional[str]
    id: typing.Optional[str]
    items: typing.Optional[typing.Any]
    maxItems: typing.Optional[int]
    maxLength: typing.Optional[int]
    maxProperties: typing.Optional[int]
    maximum: typing.Optional[float]
    minItems: typing.Optional[int]
    minLength: typing.Optional[int]
    minProperties: typing.Optional[int]
    minimum: typing.Optional[float]
    multipleOf: typing.Optional[float]
    _not: typing.Optional[kubernetes.client.V1JSONSchemaPropsDict]
    nullable: typing.Optional[bool]
    oneOf: typing.Optional[list[kubernetes.client.V1JSONSchemaPropsDict]]
    pattern: typing.Optional[str]
    patternProperties: typing.Optional[
        dict[str, kubernetes.client.V1JSONSchemaPropsDict]
    ]
    properties: typing.Optional[dict[str, kubernetes.client.V1JSONSchemaPropsDict]]
    required: typing.Optional[list[str]]
    title: typing.Optional[str]
    type: typing.Optional[str]
    uniqueItems: typing.Optional[bool]
    x_kubernetes_embedded_resource: typing.Optional[bool]
    x_kubernetes_int_or_string: typing.Optional[bool]
    x_kubernetes_list_map_keys: typing.Optional[list[str]]
    x_kubernetes_list_type: typing.Optional[str]
    x_kubernetes_map_type: typing.Optional[str]
    x_kubernetes_preserve_unknown_fields: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1Volume:
    aws_elastic_block_store: typing.Optional[
        kubernetes.client.V1AWSElasticBlockStoreVolumeSource
    ]
    azure_disk: typing.Optional[kubernetes.client.V1AzureDiskVolumeSource]
    azure_file: typing.Optional[kubernetes.client.V1AzureFileVolumeSource]
    cephfs: typing.Optional[kubernetes.client.V1CephFSVolumeSource]
    cinder: typing.Optional[kubernetes.client.V1CinderVolumeSource]
    config_map: typing.Optional[kubernetes.client.V1ConfigMapVolumeSource]
    csi: typing.Optional[kubernetes.client.V1CSIVolumeSource]
    downward_api: typing.Optional[kubernetes.client.V1DownwardAPIVolumeSource]
    empty_dir: typing.Optional[kubernetes.client.V1EmptyDirVolumeSource]
    ephemeral: typing.Optional[kubernetes.client.V1EphemeralVolumeSource]
    fc: typing.Optional[kubernetes.client.V1FCVolumeSource]
    flex_volume: typing.Optional[kubernetes.client.V1FlexVolumeSource]
    flocker: typing.Optional[kubernetes.client.V1FlockerVolumeSource]
    gce_persistent_disk: typing.Optional[
        kubernetes.client.V1GCEPersistentDiskVolumeSource
    ]
    git_repo: typing.Optional[kubernetes.client.V1GitRepoVolumeSource]
    glusterfs: typing.Optional[kubernetes.client.V1GlusterfsVolumeSource]
    host_path: typing.Optional[kubernetes.client.V1HostPathVolumeSource]
    iscsi: typing.Optional[kubernetes.client.V1ISCSIVolumeSource]
    name: str
    nfs: typing.Optional[kubernetes.client.V1NFSVolumeSource]
    persistent_volume_claim: typing.Optional[
        kubernetes.client.V1PersistentVolumeClaimVolumeSource
    ]
    photon_persistent_disk: typing.Optional[
        kubernetes.client.V1PhotonPersistentDiskVolumeSource
    ]
    portworx_volume: typing.Optional[kubernetes.client.V1PortworxVolumeSource]
    projected: typing.Optional[kubernetes.client.V1ProjectedVolumeSource]
    quobyte: typing.Optional[kubernetes.client.V1QuobyteVolumeSource]
    rbd: typing.Optional[kubernetes.client.V1RBDVolumeSource]
    scale_io: typing.Optional[kubernetes.client.V1ScaleIOVolumeSource]
    secret: typing.Optional[kubernetes.client.V1SecretVolumeSource]
    storageos: typing.Optional[kubernetes.client.V1StorageOSVolumeSource]
    vsphere_volume: typing.Optional[kubernetes.client.V1VsphereVirtualDiskVolumeSource]
    def __init__(
        self,
        *,
        aws_elastic_block_store: typing.Optional[
            kubernetes.client.V1AWSElasticBlockStoreVolumeSource
        ] = ...,
        azure_disk: typing.Optional[kubernetes.client.V1AzureDiskVolumeSource] = ...,
        azure_file: typing.Optional[kubernetes.client.V1AzureFileVolumeSource] = ...,
        cephfs: typing.Optional[kubernetes.client.V1CephFSVolumeSource] = ...,
        cinder: typing.Optional[kubernetes.client.V1CinderVolumeSource] = ...,
        config_map: typing.Optional[kubernetes.client.V1ConfigMapVolumeSource] = ...,
        csi: typing.Optional[kubernetes.client.V1CSIVolumeSource] = ...,
        downward_api: typing.Optional[
            kubernetes.client.V1DownwardAPIVolumeSource
        ] = ...,
        empty_dir: typing.Optional[kubernetes.client.V1EmptyDirVolumeSource] = ...,
        ephemeral: typing.Optional[kubernetes.client.V1EphemeralVolumeSource] = ...,
        fc: typing.Optional[kubernetes.client.V1FCVolumeSource] = ...,
        flex_volume: typing.Optional[kubernetes.client.V1FlexVolumeSource] = ...,
        flocker: typing.Optional[kubernetes.client.V1FlockerVolumeSource] = ...,
        gce_persistent_disk: typing.Optional[
            kubernetes.client.V1GCEPersistentDiskVolumeSource
        ] = ...,
        git_repo: typing.Optional[kubernetes.client.V1GitRepoVolumeSource] = ...,
        glusterfs: typing.Optional[kubernetes.client.V1GlusterfsVolumeSource] = ...,
        host_path: typing.Optional[kubernetes.client.V1HostPathVolumeSource] = ...,
        iscsi: typing.Optional[kubernetes.client.V1ISCSIVolumeSource] = ...,
        name: str,
        nfs: typing.Optional[kubernetes.client.V1NFSVolumeSource] = ...,
        persistent_volume_claim: typing.Optional[
            kubernetes.client.V1PersistentVolumeClaimVolumeSource
        ] = ...,
        photon_persistent_disk: typing.Optional[
            kubernetes.client.V1PhotonPersistentDiskVolumeSource
        ] = ...,
        portworx_volume: typing.Optional[
            kubernetes.client.V1PortworxVolumeSource
        ] = ...,
        projected: typing.Optional[kubernetes.client.V1ProjectedVolumeSource] = ...,
        quobyte: typing.Optional[kubernetes.client.V1QuobyteVolumeSource] = ...,
        rbd: typing.Optional[kubernetes.client.V1RBDVolumeSource] = ...,
        scale_io: typing.Optional[kubernetes.client.V1ScaleIOVolumeSource] = ...,
        secret: typing.Optional[kubernetes.client.V1SecretVolumeSource] = ...,
        storageos: typing.Optional[kubernetes.client.V1StorageOSVolumeSource] = ...,
        vsphere_volume: typing.Optional[
            kubernetes.client.V1VsphereVirtualDiskVolumeSource
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1VolumeDict: ...

class V1VolumeDict(typing.TypedDict, total=False):
    awsElasticBlockStore: typing.Optional[
        kubernetes.client.V1AWSElasticBlockStoreVolumeSourceDict
    ]
    azureDisk: typing.Optional[kubernetes.client.V1AzureDiskVolumeSourceDict]
    azureFile: typing.Optional[kubernetes.client.V1AzureFileVolumeSourceDict]
    cephfs: typing.Optional[kubernetes.client.V1CephFSVolumeSourceDict]
    cinder: typing.Optional[kubernetes.client.V1CinderVolumeSourceDict]
    configMap: typing.Optional[kubernetes.client.V1ConfigMapVolumeSourceDict]
    csi: typing.Optional[kubernetes.client.V1CSIVolumeSourceDict]
    downwardAPI: typing.Optional[kubernetes.client.V1DownwardAPIVolumeSourceDict]
    emptyDir: typing.Optional[kubernetes.client.V1EmptyDirVolumeSourceDict]
    ephemeral: typing.Optional[kubernetes.client.V1EphemeralVolumeSourceDict]
    fc: typing.Optional[kubernetes.client.V1FCVolumeSourceDict]
    flexVolume: typing.Optional[kubernetes.client.V1FlexVolumeSourceDict]
    flocker: typing.Optional[kubernetes.client.V1FlockerVolumeSourceDict]
    gcePersistentDisk: typing.Optional[
        kubernetes.client.V1GCEPersistentDiskVolumeSourceDict
    ]
    gitRepo: typing.Optional[kubernetes.client.V1GitRepoVolumeSourceDict]
    glusterfs: typing.Optional[kubernetes.client.V1GlusterfsVolumeSourceDict]
    hostPath: typing.Optional[kubernetes.client.V1HostPathVolumeSourceDict]
    iscsi: typing.Optional[kubernetes.client.V1ISCSIVolumeSourceDict]
    name: str
    nfs: typing.Optional[kubernetes.client.V1NFSVolumeSourceDict]
    persistentVolumeClaim: typing.Optional[
        kubernetes.client.V1PersistentVolumeClaimVolumeSourceDict
    ]
    photonPersistentDisk: typing.Optional[
        kubernetes.client.V1PhotonPersistentDiskVolumeSourceDict
    ]
    portworxVolume: typing.Optional[kubernetes.client.V1PortworxVolumeSourceDict]
    projected: typing.Optional[kubernetes.client.V1ProjectedVolumeSourceDict]
    quobyte: typing.Optional[kubernetes.client.V1QuobyteVolumeSourceDict]
    rbd: typing.Optional[kubernetes.client.V1RBDVolumeSourceDict]
    scaleIO: typing.Optional[kubernetes.client.V1ScaleIOVolumeSourceDict]
    secret: typing.Optional[kubernetes.client.V1SecretVolumeSourceDict]
    storageos: typing.Optional[kubernetes.client.V1StorageOSVolumeSourceDict]
    vsphereVolume: typing.Optional[
        kubernetes.client.V1VsphereVirtualDiskVolumeSourceDict
    ]



import datetime
import typing

import kubernetes.client

class V1CustomResourceDefinitionVersion:
    additional_printer_columns: typing.Optional[
        list[kubernetes.client.V1CustomResourceColumnDefinition]
    ]
    deprecated: typing.Optional[bool]
    deprecation_warning: typing.Optional[str]
    name: str
    schema: typing.Optional[kubernetes.client.V1CustomResourceValidation]
    served: bool
    storage: bool
    subresources: typing.Optional[kubernetes.client.V1CustomResourceSubresources]
    def __init__(
        self,
        *,
        additional_printer_columns: typing.Optional[
            list[kubernetes.client.V1CustomResourceColumnDefinition]
        ] = ...,
        deprecated: typing.Optional[bool] = ...,
        deprecation_warning: typing.Optional[str] = ...,
        name: str,
        schema: typing.Optional[kubernetes.client.V1CustomResourceValidation] = ...,
        served: bool,
        storage: bool,
        subresources: typing.Optional[
            kubernetes.client.V1CustomResourceSubresources
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1CustomResourceDefinitionVersionDict: ...

class V1CustomResourceDefinitionVersionDict(typing.TypedDict, total=False):
    additionalPrinterColumns: typing.Optional[
        list[kubernetes.client.V1CustomResourceColumnDefinitionDict]
    ]
    deprecated: typing.Optional[bool]
    deprecationWarning: typing.Optional[str]
    name: str
    schema: typing.Optional[kubernetes.client.V1CustomResourceValidationDict]
    served: bool
    storage: bool
    subresources: typing.Optional[kubernetes.client.V1CustomResourceSubresourcesDict]



import datetime
import typing

import kubernetes.client

class V1NodeAddress:
    address: str
    type: str
    def __init__(self, *, address: str, type: str) -> None: ...
    def to_dict(self) -> V1NodeAddressDict: ...

class V1NodeAddressDict(typing.TypedDict, total=False):
    address: str
    type: str



import datetime
import typing

import kubernetes.client

class V1Capabilities:
    add: typing.Optional[list[str]]
    drop: typing.Optional[list[str]]
    def __init__(
        self,
        *,
        add: typing.Optional[list[str]] = ...,
        drop: typing.Optional[list[str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1CapabilitiesDict: ...

class V1CapabilitiesDict(typing.TypedDict, total=False):
    add: typing.Optional[list[str]]
    drop: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class V1StatusCause:
    field: typing.Optional[str]
    message: typing.Optional[str]
    reason: typing.Optional[str]
    def __init__(
        self,
        *,
        field: typing.Optional[str] = ...,
        message: typing.Optional[str] = ...,
        reason: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1StatusCauseDict: ...

class V1StatusCauseDict(typing.TypedDict, total=False):
    field: typing.Optional[str]
    message: typing.Optional[str]
    reason: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1alpha1RuntimeClassSpec:
    overhead: typing.Optional[kubernetes.client.V1alpha1Overhead]
    runtime_handler: str
    scheduling: typing.Optional[kubernetes.client.V1alpha1Scheduling]
    def __init__(
        self,
        *,
        overhead: typing.Optional[kubernetes.client.V1alpha1Overhead] = ...,
        runtime_handler: str,
        scheduling: typing.Optional[kubernetes.client.V1alpha1Scheduling] = ...
    ) -> None: ...
    def to_dict(self) -> V1alpha1RuntimeClassSpecDict: ...

class V1alpha1RuntimeClassSpecDict(typing.TypedDict, total=False):
    overhead: typing.Optional[kubernetes.client.V1alpha1OverheadDict]
    runtimeHandler: str
    scheduling: typing.Optional[kubernetes.client.V1alpha1SchedulingDict]



import datetime
import typing

import kubernetes.client

class V1Container:
    args: typing.Optional[list[str]]
    command: typing.Optional[list[str]]
    env: typing.Optional[list[kubernetes.client.V1EnvVar]]
    env_from: typing.Optional[list[kubernetes.client.V1EnvFromSource]]
    image: typing.Optional[str]
    image_pull_policy: typing.Optional[str]
    lifecycle: typing.Optional[kubernetes.client.V1Lifecycle]
    liveness_probe: typing.Optional[kubernetes.client.V1Probe]
    name: str
    ports: typing.Optional[list[kubernetes.client.V1ContainerPort]]
    readiness_probe: typing.Optional[kubernetes.client.V1Probe]
    resources: typing.Optional[kubernetes.client.V1ResourceRequirements]
    security_context: typing.Optional[kubernetes.client.V1SecurityContext]
    startup_probe: typing.Optional[kubernetes.client.V1Probe]
    stdin: typing.Optional[bool]
    stdin_once: typing.Optional[bool]
    termination_message_path: typing.Optional[str]
    termination_message_policy: typing.Optional[str]
    tty: typing.Optional[bool]
    volume_devices: typing.Optional[list[kubernetes.client.V1VolumeDevice]]
    volume_mounts: typing.Optional[list[kubernetes.client.V1VolumeMount]]
    working_dir: typing.Optional[str]
    def __init__(
        self,
        *,
        args: typing.Optional[list[str]] = ...,
        command: typing.Optional[list[str]] = ...,
        env: typing.Optional[list[kubernetes.client.V1EnvVar]] = ...,
        env_from: typing.Optional[list[kubernetes.client.V1EnvFromSource]] = ...,
        image: typing.Optional[str] = ...,
        image_pull_policy: typing.Optional[str] = ...,
        lifecycle: typing.Optional[kubernetes.client.V1Lifecycle] = ...,
        liveness_probe: typing.Optional[kubernetes.client.V1Probe] = ...,
        name: str,
        ports: typing.Optional[list[kubernetes.client.V1ContainerPort]] = ...,
        readiness_probe: typing.Optional[kubernetes.client.V1Probe] = ...,
        resources: typing.Optional[kubernetes.client.V1ResourceRequirements] = ...,
        security_context: typing.Optional[kubernetes.client.V1SecurityContext] = ...,
        startup_probe: typing.Optional[kubernetes.client.V1Probe] = ...,
        stdin: typing.Optional[bool] = ...,
        stdin_once: typing.Optional[bool] = ...,
        termination_message_path: typing.Optional[str] = ...,
        termination_message_policy: typing.Optional[str] = ...,
        tty: typing.Optional[bool] = ...,
        volume_devices: typing.Optional[list[kubernetes.client.V1VolumeDevice]] = ...,
        volume_mounts: typing.Optional[list[kubernetes.client.V1VolumeMount]] = ...,
        working_dir: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1ContainerDict: ...

class V1ContainerDict(typing.TypedDict, total=False):
    args: typing.Optional[list[str]]
    command: typing.Optional[list[str]]
    env: typing.Optional[list[kubernetes.client.V1EnvVarDict]]
    envFrom: typing.Optional[list[kubernetes.client.V1EnvFromSourceDict]]
    image: typing.Optional[str]
    imagePullPolicy: typing.Optional[str]
    lifecycle: typing.Optional[kubernetes.client.V1LifecycleDict]
    livenessProbe: typing.Optional[kubernetes.client.V1ProbeDict]
    name: str
    ports: typing.Optional[list[kubernetes.client.V1ContainerPortDict]]
    readinessProbe: typing.Optional[kubernetes.client.V1ProbeDict]
    resources: typing.Optional[kubernetes.client.V1ResourceRequirementsDict]
    securityContext: typing.Optional[kubernetes.client.V1SecurityContextDict]
    startupProbe: typing.Optional[kubernetes.client.V1ProbeDict]
    stdin: typing.Optional[bool]
    stdinOnce: typing.Optional[bool]
    terminationMessagePath: typing.Optional[str]
    terminationMessagePolicy: typing.Optional[str]
    tty: typing.Optional[bool]
    volumeDevices: typing.Optional[list[kubernetes.client.V1VolumeDeviceDict]]
    volumeMounts: typing.Optional[list[kubernetes.client.V1VolumeMountDict]]
    workingDir: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1NodeStatus:
    addresses: typing.Optional[list[kubernetes.client.V1NodeAddress]]
    allocatable: typing.Optional[dict[str, str]]
    capacity: typing.Optional[dict[str, str]]
    conditions: typing.Optional[list[kubernetes.client.V1NodeCondition]]
    config: typing.Optional[kubernetes.client.V1NodeConfigStatus]
    daemon_endpoints: typing.Optional[kubernetes.client.V1NodeDaemonEndpoints]
    images: typing.Optional[list[kubernetes.client.V1ContainerImage]]
    node_info: typing.Optional[kubernetes.client.V1NodeSystemInfo]
    phase: typing.Optional[str]
    volumes_attached: typing.Optional[list[kubernetes.client.V1AttachedVolume]]
    volumes_in_use: typing.Optional[list[str]]
    def __init__(
        self,
        *,
        addresses: typing.Optional[list[kubernetes.client.V1NodeAddress]] = ...,
        allocatable: typing.Optional[dict[str, str]] = ...,
        capacity: typing.Optional[dict[str, str]] = ...,
        conditions: typing.Optional[list[kubernetes.client.V1NodeCondition]] = ...,
        config: typing.Optional[kubernetes.client.V1NodeConfigStatus] = ...,
        daemon_endpoints: typing.Optional[
            kubernetes.client.V1NodeDaemonEndpoints
        ] = ...,
        images: typing.Optional[list[kubernetes.client.V1ContainerImage]] = ...,
        node_info: typing.Optional[kubernetes.client.V1NodeSystemInfo] = ...,
        phase: typing.Optional[str] = ...,
        volumes_attached: typing.Optional[
            list[kubernetes.client.V1AttachedVolume]
        ] = ...,
        volumes_in_use: typing.Optional[list[str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1NodeStatusDict: ...

class V1NodeStatusDict(typing.TypedDict, total=False):
    addresses: typing.Optional[list[kubernetes.client.V1NodeAddressDict]]
    allocatable: typing.Optional[dict[str, str]]
    capacity: typing.Optional[dict[str, str]]
    conditions: typing.Optional[list[kubernetes.client.V1NodeConditionDict]]
    config: typing.Optional[kubernetes.client.V1NodeConfigStatusDict]
    daemonEndpoints: typing.Optional[kubernetes.client.V1NodeDaemonEndpointsDict]
    images: typing.Optional[list[kubernetes.client.V1ContainerImageDict]]
    nodeInfo: typing.Optional[kubernetes.client.V1NodeSystemInfoDict]
    phase: typing.Optional[str]
    volumesAttached: typing.Optional[list[kubernetes.client.V1AttachedVolumeDict]]
    volumesInUse: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class NetworkingV1beta1IngressRule:
    host: typing.Optional[str]
    http: typing.Optional[kubernetes.client.NetworkingV1beta1HTTPIngressRuleValue]
    def __init__(
        self,
        *,
        host: typing.Optional[str] = ...,
        http: typing.Optional[
            kubernetes.client.NetworkingV1beta1HTTPIngressRuleValue
        ] = ...
    ) -> None: ...
    def to_dict(self) -> NetworkingV1beta1IngressRuleDict: ...

class NetworkingV1beta1IngressRuleDict(typing.TypedDict, total=False):
    host: typing.Optional[str]
    http: typing.Optional[kubernetes.client.NetworkingV1beta1HTTPIngressRuleValueDict]



import datetime
import typing

import kubernetes.client

class V1DaemonSetSpec:
    min_ready_seconds: typing.Optional[int]
    revision_history_limit: typing.Optional[int]
    selector: kubernetes.client.V1LabelSelector
    template: kubernetes.client.V1PodTemplateSpec
    update_strategy: typing.Optional[kubernetes.client.V1DaemonSetUpdateStrategy]
    def __init__(
        self,
        *,
        min_ready_seconds: typing.Optional[int] = ...,
        revision_history_limit: typing.Optional[int] = ...,
        selector: kubernetes.client.V1LabelSelector,
        template: kubernetes.client.V1PodTemplateSpec,
        update_strategy: typing.Optional[
            kubernetes.client.V1DaemonSetUpdateStrategy
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1DaemonSetSpecDict: ...

class V1DaemonSetSpecDict(typing.TypedDict, total=False):
    minReadySeconds: typing.Optional[int]
    revisionHistoryLimit: typing.Optional[int]
    selector: kubernetes.client.V1LabelSelectorDict
    template: kubernetes.client.V1PodTemplateSpecDict
    updateStrategy: typing.Optional[kubernetes.client.V1DaemonSetUpdateStrategyDict]



import datetime
import typing

import kubernetes.client

class V1EphemeralVolumeSource:
    read_only: typing.Optional[bool]
    volume_claim_template: typing.Optional[
        kubernetes.client.V1PersistentVolumeClaimTemplate
    ]
    def __init__(
        self,
        *,
        read_only: typing.Optional[bool] = ...,
        volume_claim_template: typing.Optional[
            kubernetes.client.V1PersistentVolumeClaimTemplate
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1EphemeralVolumeSourceDict: ...

class V1EphemeralVolumeSourceDict(typing.TypedDict, total=False):
    readOnly: typing.Optional[bool]
    volumeClaimTemplate: typing.Optional[
        kubernetes.client.V1PersistentVolumeClaimTemplateDict
    ]



import datetime
import typing

import kubernetes.client

class V1beta1IngressClassSpec:
    controller: typing.Optional[str]
    parameters: typing.Optional[kubernetes.client.V1TypedLocalObjectReference]
    def __init__(
        self,
        *,
        controller: typing.Optional[str] = ...,
        parameters: typing.Optional[kubernetes.client.V1TypedLocalObjectReference] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1IngressClassSpecDict: ...

class V1beta1IngressClassSpecDict(typing.TypedDict, total=False):
    controller: typing.Optional[str]
    parameters: typing.Optional[kubernetes.client.V1TypedLocalObjectReferenceDict]



import datetime
import typing

import kubernetes.client

class V1EmptyDirVolumeSource:
    medium: typing.Optional[str]
    size_limit: typing.Optional[str]
    def __init__(
        self,
        *,
        medium: typing.Optional[str] = ...,
        size_limit: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1EmptyDirVolumeSourceDict: ...

class V1EmptyDirVolumeSourceDict(typing.TypedDict, total=False):
    medium: typing.Optional[str]
    sizeLimit: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1alpha1AggregationRule:
    cluster_role_selectors: typing.Optional[list[kubernetes.client.V1LabelSelector]]
    def __init__(
        self,
        *,
        cluster_role_selectors: typing.Optional[
            list[kubernetes.client.V1LabelSelector]
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1alpha1AggregationRuleDict: ...

class V1alpha1AggregationRuleDict(typing.TypedDict, total=False):
    clusterRoleSelectors: typing.Optional[list[kubernetes.client.V1LabelSelectorDict]]



import datetime
import typing

import kubernetes.client

class V1LabelSelectorRequirement:
    key: str
    operator: str
    values: typing.Optional[list[str]]
    def __init__(
        self, *, key: str, operator: str, values: typing.Optional[list[str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1LabelSelectorRequirementDict: ...

class V1LabelSelectorRequirementDict(typing.TypedDict, total=False):
    key: str
    operator: str
    values: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class V1beta1AllowedFlexVolume:
    driver: str
    def __init__(self, *, driver: str) -> None: ...
    def to_dict(self) -> V1beta1AllowedFlexVolumeDict: ...

class V1beta1AllowedFlexVolumeDict(typing.TypedDict, total=False):
    driver: str



import datetime
import typing

import kubernetes.client

class V1HTTPIngressRuleValue:
    paths: list[kubernetes.client.V1HTTPIngressPath]
    def __init__(self, *, paths: list[kubernetes.client.V1HTTPIngressPath]) -> None: ...
    def to_dict(self) -> V1HTTPIngressRuleValueDict: ...

class V1HTTPIngressRuleValueDict(typing.TypedDict, total=False):
    paths: list[kubernetes.client.V1HTTPIngressPathDict]
